@@ -1,6 +1,8 @@
+from ._common.reindexing import reindex_faces, reindex_vertices  # noqa: F401
 from ._group_map import GroupMap  # noqa: F401
 from ._mesh import Mesh  # noqa: F401
-from ._obj import ArityException, LoadException, load as load_obj  # noqa: F401
+from ._obj.loader import ArityException, LoadException, load as load_obj  # noqa: F401
+from ._obj.writer import write as write_obj  # noqa: F401
 from ._selection.selection_object import Selection  # noqa: F401
 from ._transform.transform_object import Transform  # noqa: F401
 from .package_version import __version__  # noqa: F401
